###############
Developer guide
###############

This part of neophiles's documentation contains some supplemental information primarily of interest to people doing development on neophile itself.

The neophile code structure partly but not entirely follows the guidelines in :sqr:`072`.

.. toctree::
   :caption: Guides

   development
   release

.. toctree::
   :caption: Reference
   :maxdepth: 2

   internals
